@@ -1,6 +1,6 @@
 #! /bin/bash
 
-# $Id: build.sh,v 1.2 2002/05/18 23:15:19 jt Exp $
+# $Id: build.sh,v 1.4 2004/08/27 20:34:53 jt Exp $
 
 # vim: tabstop=4
 
@@ -15,11 +15,11 @@ pkg=procmail
 Prefix=/usr
 TmpDir=/tmp/$pkg.$$
 InstallPrefix=$TmpDir$Prefix
-BinDir=$InstallPrefix/bin
-LibDir=$InstallPrefix/lib
-ManDir=$InstallPrefix/man
-DocDir=$InstallPrefix/doc/$pkg-$version
-CygDocDir=$TmpDir/usr/doc/Cygwin
+
+DataDir=$InstallPrefix/share
+ManDir=$DataDir/man
+DocDir=$DataDir/doc/$pkg-$version
+CygDocDir=$DataDir/doc/Cygwin
 PatchDir=CYGWIN-PATCHES
 SrcDocDir=doc
 
@@ -27,14 +27,11 @@ SrcDocDir=doc
 make EXE=.exe LOCKINGTEST=100
 
 # make install
-make BASENAME=$InstallPrefix EXE=.exe install
+make BASENAME=$InstallPrefix MANDIR=$ManDir EXE=.exe install
 
 # strip executables
 find $InstallPrefix -name '*.exe' | xargs strip
 
-# create man cat dirs
-mkdir $ManDir/cat1 $ManDir/cat5
-
 # copy Cygwin procmail README file
 mkdir -p $CygDocDir
 cp $PatchDir/README $CygDocDir/$pkg-$version.README
